
 <script setup >
 import  invoiceTitle from "@/api/configuration/invoiceTitle";
 import  { sysDictData }  from "@/api/system/dict";
 import  user  from "@/api/system/user";
 import setPostParams from "../../../utils/searchParams.js";
 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:queryParams.value.name})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */
const pageParam = ref({
    total:0,
    limit:0,
    page:0,
})
const tableData = ref([]);
let  tableHeader = ref({
      typeName: "抬头类型",
      name: "抬头名称",
      taxNum: "税号",
      email: "邮箱",
      comment: "备注",
      createTimeView: "创建时间",
      updateTimeView: "更新时间"
   })

 /** 获取列表 */
const loading = ref(false);
 async function getList(val) {
      loading.value = true;
 let postParam = setPostParams(val)
      await invoiceTitle ().search(postParam).then((res) =>{
        tableData.value = res.data.list
        tableData.value.forEach((item) =>{
            if(item.type == 1){
               item.typeName = '企业单位'
            }else{
               item.typeName = '个人/非企业'
            }
        })
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
 }
 
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
   open.value = true;
   title.value = "新增";
 }
 
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   Object.keys(row).forEach(key => {  
      if (form.value.hasOwnProperty(key)) { 
      form.value[key] = row[key]; 
   } 
   });
   form.value.type = form.value.type.toString()
   form.value.id = row.id
   open.value = true;
   title.value = "修改";
 }

/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.name + '"的数据项?').then(function() {
    return invoiceTitle ().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}
 

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const title = ref("");

const data = reactive({
form:{},
queryParams: {
    name: undefined,
},
rules: {
   userId: [{ required: true, message: "请选择用户", trigger: "blur" }],
   type: [{ required: true, message: "请选择发票类型", trigger: "blur" }],
   name: [{ required: true, message: "请输入发票抬头名称", trigger: "blur" }],
   email: [{ required: true, message: "请输入邮箱", trigger: "blur" }]
},
});
const { queryParams, form, rules } = toRefs(data);


 //获取发票类型
 const invoiceTypeList = ref()
 const getType = async() =>{
   await sysDictData().searchType('invoice_type').then((res) =>{
      invoiceTypeList.value = res.data
   })
 }
 
 //获取账号列表
 const accountList = ref()
 const getAccount = async() =>{
   await user().search({limit:10000,page:1}).then((res) =>{
      accountList.value = res.data.list
   })
 }

 /** 提交按钮 */
 function submitForm() {
   proxy.$refs["formRef"].validate(valid => {
     if (valid) {
       if (form.value.id) {
         if(form.value.type == 2){
            form.value.taxNum = ''
         }
         invoiceTitle ().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       }else {
         invoiceTitle().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });;
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 
 /** 表单重置 */
 function reset() {
   form.value = {
      userId: "",
      type: "",
      name: "",
      taxNum: "",
      email: "",
      comment: "",
      sort: 1,
   };
   proxy.resetForm("formRef");
 }
 getType();
 getAccount();
 getList();
 </script>
 <template>
   <div class="app-container">
      <el-form :model="queryParams" ref="queryRef" :inline="true">
         <el-form-item prop="name">
            <el-input
               v-model="queryParams.name"
               placeholder="请输入内容"
               clearable
               style="width: 200px"
               @keyup.enter="handleQuery"
            />
         </el-form-item>
         <el-form-item>
            <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
            <el-button icon="Refresh" @click="resetQuery">重置</el-button>
         </el-form-item>
      </el-form>

      <el-row :gutter="10" class="mb8">
         <el-col :span="1.5">
            <el-button
               type="primary"
               plain
               icon="Plus"
               @click="handleAdd"
            >新增</el-button>
         </el-col>
      </el-row>
      <!--表格及分页-->
      <el-table v-loading="loading" :data="tableData">
         <el-table-column
           v-for="(item, key, index) of tableHeader"
           :prop="key.toString()"
           :label="item"
           :key="index"
           align="center"
         ></el-table-column>
         <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
            <template #default="scope">
               <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
               <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
            </template>
         </el-table-column>
       </el-table>
       <pagination
         :total="pageParam.total"
         v-model:page="pageParam.page"
         v-model:limit="pageParam.limit"
         :page-sizes="[10,20,30]"
         @pagination="getList"
       />
      <!-- 添加或修改对话框 -->
      <el-dialog :title="title" v-model="open" center>
           <el-form class="form-box" ref="formRef" :model="form" :rules="rules" label-width='auto'>
              <el-form-item label="用户"  prop="userId">
                 <el-select v-model="form.userId"  placeholder="请选择" >
                       <el-option
                       v-for="item in accountList"
                       :key="item.id"
                       :label="item.nickName"
                       :title="item.nickName"
                       :value="item.id"
                       />
                 </el-select>
              </el-form-item>
              <el-form-item label="抬头类型"  prop="type">
                 <el-select v-model="form.type"  placeholder="请选择" >
                       <el-option
                       v-for="item in invoiceTypeList"
                       :key="item.id"
                       :label="item.dictLabel"
                       :title="item.dictLabel"
                       :value="item.dictValue"
                       />
                 </el-select>
              </el-form-item>
              <el-form-item label="抬头名称"  prop="name">
                 <el-input v-model="form.name" ></el-input>
              </el-form-item>
              <el-form-item label="税号"  prop="taxNum" v-if="form.type == 1">
                 <el-input v-model="form.taxNum" ></el-input>
              </el-form-item>
              <el-form-item label="邮箱"  prop="email">
                 <el-input v-model="form.email" ></el-input>
              </el-form-item>
              <el-form-item label="备注"  prop="comment">
                 <el-input v-model="form.comment" ></el-input>
              </el-form-item>
              <el-form-item label="显示排序" prop="sort">
                 <el-input-number v-model="form.sort" controls-position="right" :min="1" />
              </el-form-item>
           </el-form>
         <template #footer>
            <div class="dialog-footer">
               <el-button type="primary" @click="submitForm">确 定</el-button>
               <el-button @click="cancel">取 消</el-button>
            </div>
         </template>
      </el-dialog>
   </div>
</template>
 <style lang = scss scoped>
     .el-form{
         width:100%;
         display: flex;
         flex-wrap: wrap;
         justify-content: space-evenly;
         .el-form-item{
             width: 45%;
         }
     }
 </style>
 